@@ -9,4 +9,4 @@
 #' @references Lohr (1999). Sampling: Design and Analysis, Duxbury, p. 230--234 and
 #'   441.
 #' @export
-roxygen()
+NULL
