@@ -12,4 +12,4 @@
 #' @references Lohr (1999). Sampling: Design and Analysis, Duxbury, p. TODO and
 #'   442. 
 #' @export
-roxygen()
+NULL
