@@ -17,4 +17,4 @@
 #' @references Lohr (1999). Sampling: Design and Analysis, Duxbury, p. TODO and
 #'   444. 
 #' @export
-roxygen()
+NULL
